@@ -43,7 +43,7 @@ async sub main() {
     $virt->stop;
 }
 
-await Future->wait_all(
+await Future->needs_all(
     Future::IO->sleep(1), # work around some futures not having ->await()
     $virt->run,
     main()
