@@ -16,7 +16,7 @@ use experimental 'signatures';
 use Future::AsyncAwait;
 use Object::Pad;
 
-class Sys::Async::Virt::Connection::Factory v0.4.0;
+class Sys::Async::Virt::Connection::Factory v0.5.0;
 
 use Carp qw(croak);
 use Log::Any qw($log);
@@ -27,7 +27,7 @@ our @default_drivers = (
     { transport => 'unix', class => 'Local', host => 0 },
     # { transport => '', class => 'TCP', host => 1 },
     # { transport => 'tls', class => 'TCP' },
-    # { transport => 'tcp', class => 'TCP' },
+    { transport => 'tcp', class => 'TCP' },
     { transport => 'ext', class => 'Process' },
     { transport => 'ssh', class => 'SSH' },
     );
@@ -82,7 +82,7 @@ Sys::Async::Virt::Connection::Factory - Class for
 
 =head1 VERSION
 
-v0.4.0
+v0.5.0
 
 =head1 SYNOPSIS
 
